@@ -163,7 +163,7 @@ class WebApplication:
         async def expire_obj(cls, obj_id: str, new_lease_time: int):
             if new_lease_time > 0:
                 await asyncio.sleep(new_lease_time)
-            if hasattr(cls.instances[obj_id], '__aexist__'):
+            if hasattr(cls.instances[obj_id], '__aexit__'):
                 await cls.instances[obj_id].__aexit__(None, None, None)
             del cls.instances[obj_id]
             del cls.expiry[obj_id]
@@ -417,10 +417,15 @@ class WebApplication:
             # noinspection PyDecorator
             @staticmethod
             async def _create(*args, **kargs) -> str:
+                if '__uuid' in kargs:
+                    del kargs['__uuid']
+                    self_id = kargs['__uuid']
+                    if self_id in cls.ObjectRepo.instances:
+                        raise HTTPException(404, f"UUid {self_id} already in use. uuid's must be unique")
                 instance = clazz_(*args, **kargs)
                 if hasattr(clazz_, '__aenter__'):
                     await instance.__aenter__()
-                self_id = str(instance).split(' ')[-1][:-1]
+                self_id = kargs.get('__uuid') or str(instance).split(' ')[-1][:-1]
                 cls.ObjectRepo.instances[self_id] = instance
                 cls.ObjectRepo.expiry[self_id] = asyncio.create_task(cls.ObjectRepo.expire_obj(
                     self_id, cls.ObjectRepo.DEFAULT_OBJECT_EXPIRATION))
